import { defHttp } from '/@/utils/http/axios';
import { useMessage } from "/@/hooks/web/useMessage";

const { createConfirm } = useMessage();

enum Api {
  list = '/ggzycontentdistribution/ggzyContentDistribution/list',
  save='/ggzycontentdistribution/ggzyContentDistribution/add',
  edit='/ggzycontentdistribution/ggzyContentDistribution/edit',
  deleteOne = '/ggzycontentdistribution/ggzyContentDistribution/delete',
  releaseOne = '/ggzycontentdistribution/ggzyContentDistribution/releaseOne',
  revokeOne = '/ggzycontentdistribution/ggzyContentDistribution/revokeOne',
  deleteBatch = '/ggzycontentdistribution/ggzyContentDistribution/deleteBatch',
  releaseBatch = '/ggzycontentdistribution/ggzyContentDistribution/releaseBatch',
  revokeBatch = '/ggzycontentdistribution/ggzyContentDistribution/revokeBatch',
  importExcel = '/ggzycontentdistribution/ggzyContentDistribution/importExcel',
  exportXls = '/ggzycontentdistribution/ggzyContentDistribution/exportXls',
}

/**
 * 导出api
 * @param params
 */
export const getExportUrl = Api.exportXls;

/**
 * 导入api
 */
export const getImportUrl = Api.importExcel;

/**
 * 列表接口
 * @param params
 */
export const list = (params) => defHttp.get({ url: Api.list, params });

/**
 * 删除单个
 * @param params
 * @param handleSuccess
 */
export const deleteOne = (params,handleSuccess) => {
  return defHttp.delete({url: Api.deleteOne, params}, {joinParamsToUrl: true}).then(() => {
    handleSuccess();
  });
}
/**
 *  发布单个
 * @param params
 * @param handleSuccess
 */
export const releaseOne = (params,handleSuccess) => {
  return defHttp.delete({url: Api.releaseOne, params}, {joinParamsToUrl: true}).then(() => {
    handleSuccess();
  });
}
/**
 *  撤销单个
 * @param params
 * @param handleSuccess
 */
export const revokeOne = (params,handleSuccess) => {
  return defHttp.delete({url: Api.revokeOne, params}, {joinParamsToUrl: true}).then(() => {
    handleSuccess();
  });
}

/**
 * 批量删除
 * @param params
 * @param handleSuccess
 */
export const batchDelete = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认删除',
    content: '是否删除选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.deleteBatch, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}


export const batchRelease = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认发布',
    content: '是否发布选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.releaseBatch, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}


export const batchRevoke = (params, handleSuccess) => {
  createConfirm({
    iconType: 'warning',
    title: '确认撤销',
    content: '是否撤销选中数据',
    okText: '确认',
    cancelText: '取消',
    onOk: () => {
      return defHttp.delete({url: Api.revokeBatch, data: params}, {joinParamsToUrl: true}).then(() => {
        handleSuccess();
      });
    }
  });
}


/**
 * 保存或者更新
 * @param params
 * @param isUpdate
 */
export const saveOrUpdate = (params, isUpdate) => {
  let url = isUpdate ? Api.edit : Api.save;
  return defHttp.post({ url: url, params }, { isTransformResponse: false });
}
